@@ -1,5 +1,21 @@
 var NAVTREEINDEX113 =
 {
+"db/d5d/classisc_1_1lease__cmds_1_1LeaseCmdsImpl_1_1Parameters.html#aeea7645cbe14f376cdba17bca8773f4f":[3,0,1,25,6,0,4],
+"db/d5d/classisc_1_1lease__cmds_1_1LeaseCmdsImpl_1_1Parameters.html#aeea7645cbe14f376cdba17bca8773f4f":[4,0,0,22,6,0,4],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html":[3,0,1,10,30],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html":[4,0,0,9,30],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a1132bd4d0d41825e95cda514770e93c0":[3,0,1,10,30,2],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a1132bd4d0d41825e95cda514770e93c0":[4,0,0,9,30,2],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a18a44cba691c99b9703c5ddc4487709d":[3,0,1,10,30,1],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a18a44cba691c99b9703c5ddc4487709d":[4,0,0,9,30,1],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a290ce8b3c2204399b24508d902d55b01":[3,0,1,10,30,6],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a290ce8b3c2204399b24508d902d55b01":[4,0,0,9,30,6],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a2a289139a008b8eb1d37e7e5097b9fcd":[3,0,1,10,30,0],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a2a289139a008b8eb1d37e7e5097b9fcd":[4,0,0,9,30,0],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a2d1349da7d94501152c64695545eba85":[3,0,1,10,30,9],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a2d1349da7d94501152c64695545eba85":[4,0,0,9,30,9],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a4028d0e31a77fb05305747c95685fa8a":[3,0,1,10,30,7],
+"db/d62/classisc_1_1db_1_1MySqlBinding.html#a4028d0e31a77fb05305747c95685fa8a":[4,0,0,9,30,7],
 "db/d62/classisc_1_1db_1_1MySqlBinding.html#a47e2eb8f800104a4f59d9cad329034af":[3,0,1,10,30,10],
 "db/d62/classisc_1_1db_1_1MySqlBinding.html#a47e2eb8f800104a4f59d9cad329034af":[4,0,0,9,30,10],
 "db/d62/classisc_1_1db_1_1MySqlBinding.html#a9d635ac22eec1957b241c53825f8013f":[3,0,1,10,30,13],
@@ -39,48 +55,48 @@ var NAVTREEINDEX113 =
 "db/d6f/dhcp6__log_8h_source.html":[5,0,0,0,3,6],
 "db/d6f/option__opaque__data__tuples_8h.html":[5,0,0,2,8,58],
 "db/d6f/option__opaque__data__tuples_8h_source.html":[5,0,0,2,8,58],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html":[3,0,1,13,226],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html":[4,0,0,11,226],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1bfbee41553ad759a45ce44a79054f69":[3,0,1,13,226,0],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1bfbee41553ad759a45ce44a79054f69":[4,0,0,11,226,0],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1e9ca820e2c941dda5e06808c04ecc2a":[3,0,1,13,226,10],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1e9ca820e2c941dda5e06808c04ecc2a":[4,0,0,11,226,10],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a582324bfebdc23884574c3eb778942a8":[3,0,1,13,226,7],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a582324bfebdc23884574c3eb778942a8":[4,0,0,11,226,7],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7496bd4ffe287801615014711d7bdff5":[3,0,1,13,226,6],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7496bd4ffe287801615014711d7bdff5":[4,0,0,11,226,6],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7f06319439d9c74898c9d22e0089a879":[3,0,1,13,226,5],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7f06319439d9c74898c9d22e0089a879":[4,0,0,11,226,5],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a81bb64a7800d7f9dfab7e6abbd9639fa":[3,0,1,13,226,4],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a81bb64a7800d7f9dfab7e6abbd9639fa":[4,0,0,11,226,4],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a8ccab3074a96f7e9a5e9dba98f689f55":[3,0,1,13,226,1],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a8ccab3074a96f7e9a5e9dba98f689f55":[4,0,0,11,226,1],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a93795e03c944b1a4d0d50a9f2c2d99f0":[3,0,1,13,226,2],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a93795e03c944b1a4d0d50a9f2c2d99f0":[4,0,0,11,226,2],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a9e52987d33196fb5077423d448fa5e23":[3,0,1,13,226,8],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a9e52987d33196fb5077423d448fa5e23":[4,0,0,11,226,8],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#aada79ac310a38eac182f19ed722c5228":[3,0,1,13,226,9],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#aada79ac310a38eac182f19ed722c5228":[4,0,0,11,226,9],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#ac506e2c84b937ea17839689f3c5d0088":[3,0,1,13,226,3],
-"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#ac506e2c84b937ea17839689f3c5d0088":[4,0,0,11,226,3],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html":[3,0,1,13,227],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html":[4,0,0,11,227],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1bfbee41553ad759a45ce44a79054f69":[3,0,1,13,227,0],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1bfbee41553ad759a45ce44a79054f69":[4,0,0,11,227,0],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1e9ca820e2c941dda5e06808c04ecc2a":[3,0,1,13,227,10],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a1e9ca820e2c941dda5e06808c04ecc2a":[4,0,0,11,227,10],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a582324bfebdc23884574c3eb778942a8":[3,0,1,13,227,7],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a582324bfebdc23884574c3eb778942a8":[4,0,0,11,227,7],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7496bd4ffe287801615014711d7bdff5":[3,0,1,13,227,6],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7496bd4ffe287801615014711d7bdff5":[4,0,0,11,227,6],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7f06319439d9c74898c9d22e0089a879":[3,0,1,13,227,5],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a7f06319439d9c74898c9d22e0089a879":[4,0,0,11,227,5],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a81bb64a7800d7f9dfab7e6abbd9639fa":[3,0,1,13,227,4],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a81bb64a7800d7f9dfab7e6abbd9639fa":[4,0,0,11,227,4],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a8ccab3074a96f7e9a5e9dba98f689f55":[3,0,1,13,227,1],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a8ccab3074a96f7e9a5e9dba98f689f55":[4,0,0,11,227,1],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a93795e03c944b1a4d0d50a9f2c2d99f0":[3,0,1,13,227,2],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a93795e03c944b1a4d0d50a9f2c2d99f0":[4,0,0,11,227,2],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a9e52987d33196fb5077423d448fa5e23":[3,0,1,13,227,8],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#a9e52987d33196fb5077423d448fa5e23":[4,0,0,11,227,8],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#aada79ac310a38eac182f19ed722c5228":[3,0,1,13,227,9],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#aada79ac310a38eac182f19ed722c5228":[4,0,0,11,227,9],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#ac506e2c84b937ea17839689f3c5d0088":[3,0,1,13,227,3],
+"db/d73/classisc_1_1dhcp_1_1OptionIntArray.html#ac506e2c84b937ea17839689f3c5d0088":[4,0,0,11,227,3],
 "db/d74/classisc_1_1http_1_1HttpConnectionError.html":[3,0,1,24,12],
 "db/d74/classisc_1_1http_1_1HttpConnectionError.html":[4,0,0,21,12],
 "db/d74/classisc_1_1http_1_1HttpConnectionError.html#af6cf0d656dffbd7ac971b371ccfa80ae":[3,0,1,24,12,0],
 "db/d74/classisc_1_1http_1_1HttpConnectionError.html#af6cf0d656dffbd7ac971b371ccfa80ae":[4,0,0,21,12,0],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html":[3,0,1,13,305],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html":[4,0,0,11,305],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a57e194457e494b04da9f757d32d2e3ba":[3,0,1,13,305,5],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a57e194457e494b04da9f757d32d2e3ba":[4,0,0,11,305,5],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a866ee8ed12142a0d2ce3f95d8bde6621":[3,0,1,13,305,2],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a866ee8ed12142a0d2ce3f95d8bde6621":[4,0,0,11,305,2],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#aa06b224523b4449999ffa9954ed57096":[3,0,1,13,305,1],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#aa06b224523b4449999ffa9954ed57096":[4,0,0,11,305,1],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#abd42c3abd8c24fbce0871d2423982027":[3,0,1,13,305,3],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#abd42c3abd8c24fbce0871d2423982027":[4,0,0,11,305,3],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae4ebccc22fbe5cb69c813425d9baa8c7":[3,0,1,13,305,0],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae4ebccc22fbe5cb69c813425d9baa8c7":[4,0,0,11,305,0],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae974bddec1b9d13e24ec09fd3d9a3860":[3,0,1,13,305,4],
-"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae974bddec1b9d13e24ec09fd3d9a3860":[4,0,0,11,305,4],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html":[3,0,1,13,306],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html":[4,0,0,11,306],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a57e194457e494b04da9f757d32d2e3ba":[3,0,1,13,306,5],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a57e194457e494b04da9f757d32d2e3ba":[4,0,0,11,306,5],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a866ee8ed12142a0d2ce3f95d8bde6621":[3,0,1,13,306,2],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#a866ee8ed12142a0d2ce3f95d8bde6621":[4,0,0,11,306,2],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#aa06b224523b4449999ffa9954ed57096":[3,0,1,13,306,1],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#aa06b224523b4449999ffa9954ed57096":[4,0,0,11,306,1],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#abd42c3abd8c24fbce0871d2423982027":[3,0,1,13,306,3],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#abd42c3abd8c24fbce0871d2423982027":[4,0,0,11,306,3],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae4ebccc22fbe5cb69c813425d9baa8c7":[3,0,1,13,306,0],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae4ebccc22fbe5cb69c813425d9baa8c7":[4,0,0,11,306,0],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae974bddec1b9d13e24ec09fd3d9a3860":[3,0,1,13,306,4],
+"db/d75/structisc_1_1dhcp_1_1SocketInfo.html#ae974bddec1b9d13e24ec09fd3d9a3860":[4,0,0,11,306,4],
 "db/d77/classisc_1_1agent_1_1CtrlAgentProcess.html":[3,0,1,0,7],
 "db/d77/classisc_1_1agent_1_1CtrlAgentProcess.html":[4,0,0,0,7],
 "db/d77/classisc_1_1agent_1_1CtrlAgentProcess.html#a0964e97b56c8ef92dd0bae08ef66a7c0":[3,0,1,0,7,7],
@@ -157,40 +173,40 @@ var NAVTREEINDEX113 =
 "db/d7b/classisc_1_1agent_1_1AgentParser_1_1context.html#a616830f360de202e289c5357f0d46e6e":[4,0,0,0,0,2,2],
 "db/d7b/classisc_1_1agent_1_1AgentParser_1_1context.html#afebd3b640901a7c0b2c3bc8ad64adc63":[3,0,1,0,0,2,1],
 "db/d7b/classisc_1_1agent_1_1AgentParser_1_1context.html#afebd3b640901a7c0b2c3bc8ad64adc63":[4,0,0,0,0,2,1],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html":[3,0,1,13,253],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html":[4,0,0,11,253],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a2d6021cc069323bab4a86b19ad5f7c89":[3,0,1,13,253,1],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a2d6021cc069323bab4a86b19ad5f7c89":[4,0,0,11,253,1],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a859d6d12dd6a9aa901fec597c8e3c864":[3,0,1,13,253,2],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a859d6d12dd6a9aa901fec597c8e3c864":[4,0,0,11,253,2],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#aa7c9927aed61306c7b1438ce42b7c70f":[3,0,1,13,253,0],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#aa7c9927aed61306c7b1438ce42b7c70f":[4,0,0,11,253,0],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#ade17d30b2359172d18b8bf8e24204c62":[3,0,1,13,253,3],
-"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#ade17d30b2359172d18b8bf8e24204c62":[4,0,0,11,253,3],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html":[3,0,1,13,254],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html":[4,0,0,11,254],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a2d6021cc069323bab4a86b19ad5f7c89":[3,0,1,13,254,1],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a2d6021cc069323bab4a86b19ad5f7c89":[4,0,0,11,254,1],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a859d6d12dd6a9aa901fec597c8e3c864":[3,0,1,13,254,2],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#a859d6d12dd6a9aa901fec597c8e3c864":[4,0,0,11,254,2],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#aa7c9927aed61306c7b1438ce42b7c70f":[3,0,1,13,254,0],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#aa7c9927aed61306c7b1438ce42b7c70f":[4,0,0,11,254,0],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#ade17d30b2359172d18b8bf8e24204c62":[3,0,1,13,254,3],
+"db/d7b/classisc_1_1dhcp_1_1PktFilter6.html#ade17d30b2359172d18b8bf8e24204c62":[4,0,0,11,254,3],
 "db/d7c/utf8_8h.html":[5,0,0,2,23,0,3],
 "db/d7c/utf8_8h_source.html":[5,0,0,2,23,0,3],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html":[3,0,1,13,170],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html":[4,0,0,11,170],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a0c1a8b7996c9a811d47eba76124d41e2":[3,0,1,13,170,2],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a0c1a8b7996c9a811d47eba76124d41e2":[4,0,0,11,170,2],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a2349b7e405330852bf14cd9834d0e6d1":[3,0,1,13,170,0],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a2349b7e405330852bf14cd9834d0e6d1":[4,0,0,11,170,0],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a88576acc85889273eba78100eb6339a3":[3,0,1,13,170,3],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a88576acc85889273eba78100eb6339a3":[4,0,0,11,170,3],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#aaccdf2c80d158fd133a2f07571bba0c5":[3,0,1,13,170,4],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#aaccdf2c80d158fd133a2f07571bba0c5":[4,0,0,11,170,4],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#afcfcd894a4d1ddf6577eaafa351802be":[3,0,1,13,170,1],
-"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#afcfcd894a4d1ddf6577eaafa351802be":[4,0,0,11,170,1],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html":[3,0,1,13,230],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html":[4,0,0,11,230],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a01b23a920a262caeb120b9d44063eaa0":[3,0,1,13,230,1],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a01b23a920a262caeb120b9d44063eaa0":[4,0,0,11,230,1],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a33a0eb843e37c694cbf90f123aea8abe":[3,0,1,13,230,0],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a33a0eb843e37c694cbf90f123aea8abe":[4,0,0,11,230,0],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#ab62cb1f01f3547b895d28f0435892dc9":[3,0,1,13,230,2],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#ab62cb1f01f3547b895d28f0435892dc9":[4,0,0,11,230,2],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#add5b7c1580ea972fbb7176ad5021cd53":[3,0,1,13,230,3],
-"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#add5b7c1580ea972fbb7176ad5021cd53":[4,0,0,11,230,3],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html":[3,0,1,13,171],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html":[4,0,0,11,171],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a0c1a8b7996c9a811d47eba76124d41e2":[3,0,1,13,171,2],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a0c1a8b7996c9a811d47eba76124d41e2":[4,0,0,11,171,2],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a2349b7e405330852bf14cd9834d0e6d1":[3,0,1,13,171,0],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a2349b7e405330852bf14cd9834d0e6d1":[4,0,0,11,171,0],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a88576acc85889273eba78100eb6339a3":[3,0,1,13,171,3],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#a88576acc85889273eba78100eb6339a3":[4,0,0,11,171,3],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#aaccdf2c80d158fd133a2f07571bba0c5":[3,0,1,13,171,4],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#aaccdf2c80d158fd133a2f07571bba0c5":[4,0,0,11,171,4],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#afcfcd894a4d1ddf6577eaafa351802be":[3,0,1,13,171,1],
+"db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html#afcfcd894a4d1ddf6577eaafa351802be":[4,0,0,11,171,1],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html":[3,0,1,13,231],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html":[4,0,0,11,231],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a01b23a920a262caeb120b9d44063eaa0":[3,0,1,13,231,1],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a01b23a920a262caeb120b9d44063eaa0":[4,0,0,11,231,1],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a33a0eb843e37c694cbf90f123aea8abe":[3,0,1,13,231,0],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#a33a0eb843e37c694cbf90f123aea8abe":[4,0,0,11,231,0],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#ab62cb1f01f3547b895d28f0435892dc9":[3,0,1,13,231,2],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#ab62cb1f01f3547b895d28f0435892dc9":[4,0,0,11,231,2],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#add5b7c1580ea972fbb7176ad5021cd53":[3,0,1,13,231,3],
+"db/d7e/classisc_1_1dhcp_1_1OptionSpace6.html#add5b7c1580ea972fbb7176ad5021cd53":[4,0,0,11,231,3],
 "db/d7e/opcode_8cc.html":[5,0,0,2,11,22],
 "db/d7e/opcode_8cc_source.html":[5,0,0,2,11,22],
 "db/d80/classisc_1_1d2_1_1NameChangeTransactionError.html":[3,0,1,8,42],
@@ -233,21 +249,5 @@ var NAVTREEINDEX113 =
 "db/d83/run__all_8cc_source.html":[5,0,0,2,23,2,10],
 "db/d85/classisc_1_1dhcp_1_1Dhcp4o6IpcError.html":[3,0,1,13,68],
 "db/d85/classisc_1_1dhcp_1_1Dhcp4o6IpcError.html":[4,0,0,11,68],
-"db/d85/classisc_1_1dhcp_1_1Dhcp4o6IpcError.html#a3d28109b1622c57195ec52da2613faa0":[3,0,1,13,68,0],
-"db/d85/classisc_1_1dhcp_1_1Dhcp4o6IpcError.html#a3d28109b1622c57195ec52da2613faa0":[4,0,0,11,68,0],
-"db/d85/structisc_1_1host__cache_1_1Resv6AddressIndexTag.html":[3,0,1,22,10],
-"db/d85/structisc_1_1host__cache_1_1Resv6AddressIndexTag.html":[4,0,0,19,10],
-"db/d87/dhcp6_8h.html":[5,0,0,2,8,3],
-"db/d87/dhcp6_8h.html#a0282ae7f38bb8a4ca310c392fa0612f4":[5,0,0,2,8,3,2],
-"db/d87/dhcp6_8h.html#a04ce5d9b905fd0f004e2aa3c53623d44":[5,0,0,2,8,3,23],
-"db/d87/dhcp6_8h.html#a06c7a0a3d29ad58c0b9ecb75821724ed":[5,0,0,2,8,3,3],
-"db/d87/dhcp6_8h.html#a06ffb333c1e2be7d51844f3b90af4fbe":[5,0,0,2,8,3,41],
-"db/d87/dhcp6_8h.html#a0e014d936fb19662ed801c6cda952fe2":[5,0,0,2,8,3,4],
-"db/d87/dhcp6_8h.html#a0f84ce3388fc3068c6c66bd8df0d3d9b":[5,0,0,2,8,3,27],
-"db/d87/dhcp6_8h.html#a1342535219c904ee782e5d5d00b5b462":[5,0,0,2,8,3,30],
-"db/d87/dhcp6_8h.html#a200563867119727d6049a95c23a003ec":[5,0,0,2,8,3,36],
-"db/d87/dhcp6_8h.html#a20a20fab2084270bd0a126411d224ef4":[5,0,0,2,8,3,25],
-"db/d87/dhcp6_8h.html#a2275210100b4ecce43640bc376169d46":[5,0,0,2,8,3,37],
-"db/d87/dhcp6_8h.html#a2369d18cadb82f89513efe4c3a82af19":[5,0,0,2,8,3,13],
-"db/d87/dhcp6_8h.html#a240814d2ba69d0916e1343f72dd3a7ce":[5,0,0,2,8,3,15]
+"db/d85/classisc_1_1dhcp_1_1Dhcp4o6IpcError.html#a3d28109b1622c57195ec52da2613faa0":[3,0,1,13,68,0]
 };
